// MP3Info.h

#ifndef _MP3INFO_H
#define _MP3INFO_H

// flags
#define MP3IF_READONLY 1		// file is writeprotected

/* this is the main structure, which will be filled in */

struct MP3Info {
	// MPEG-Info
	int Layer;
	int Bitrate;
	int SampleFrequency;
	int PlayLength;
	int FileSize;
	int Version;	// Mpeg Version
	int Mode;
	short flags;		// flags, defined above
	// ID3-Tag info (the last 128 bytes of the file)
	unsigned char Tag[3];	// if Tag == "TAG" then it exists
	unsigned char SongName[30];
	unsigned char Artist[30];
	unsigned char Album[30];
	unsigned char Year[4];
	unsigned char Comment[30];
	unsigned char Genre;
};

// a useful macro
#define IsID3Tag(s) (s[0] == 'T' && s[1] == 'A' && s[2] == 'G')

// Returncodes from function GetMP3Info():
enum {
	MP3I_ERROR,   // error
	MP3I_NOID3,   // NO ID3 but MP3-INFO found
	MP3I_OK       // ID3 found
};

#define GetMP3InfoProcName "GetMP3Info"
typedef int (__stdcall *GETMP3INFOPROC)(char *, struct MP3Info *);
/* Function:
 * int GetMP3Info(char *file, struct MP3Info *mp3i)
 *
 * Parameters:
 * char *file: filename which will be scanned
 * struct MP3Info *mp3i: structure, which will be filled in
 *
 * Usage:
 * This function scans the file, and if an mp3-header is found, the
 * mp3info is filled in. When additionally an ID3-Tag is found, it will
 * be stored in the structure too.
 *
 * Return:
 * MP3I_ERROR: no mp3info is found
 * MP3I_NOID3: MP3 is found, but no ID3-tag
 * MP3I_OK:    everything has been found.
 *
 */
#endif
